pub struct TaskPoolOptions {
pub min_total_threads: usize,
pub max_total_threads: usize,
pub io: TaskPoolThreadAssignmentPolicy,
pub async_compute: TaskPoolThreadAssignmentPolicy,
pub compute: TaskPoolThreadAssignmentPolicy,
}Expand description
Helper for configuring and creating the default task pools.
For end-users who want full control, set up TaskPoolPlugin
Fields
min_total_threads: usizeIf the number of physical cores is less than min_total_threads, force using min_total_threads
max_total_threads: usizeIf the number of physical cores is greater than max_total_threads, force using max_total_threads
io: TaskPoolThreadAssignmentPolicyUsed to determine number of IO threads to allocate
async_compute: TaskPoolThreadAssignmentPolicyUsed to determine number of async compute threads to allocate
compute: TaskPoolThreadAssignmentPolicyUsed to determine number of compute threads to allocate
Implementations
Sourceimpl TaskPoolOptions
impl TaskPoolOptions
Sourcepub fn create_default_pools(&self)
pub fn create_default_pools(&self)
Inserts the default thread pools into the given resource map based on the configured values